==> loadmychunks-1.2.0%2B1.16.5%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/block/blockentity/BEBase.java <==
package com.drathonix.loadmychunks.common.block.blockentity;

import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import org.jetbrains.annotations.NotNull;

public class BEBase extends class_2586 {
    //? if >1.16.5 {
    /*public BEBase(BlockEntityType<?> blockEntityType, BlockPos blockPos, BlockState blockState) {
        super(blockEntityType, blockPos, blockState);
    }
    @Override
    public void setLevel(Level level) {
        super.setLevel(level);
        validate(level);
    }
    *///?} else {
    public BEBase(class_2591<?> blockEntityType) {
        super(blockEntityType);
    }
    @Override
    public void method_11009(class_1937 level, class_2338 blockPos) {
        super.method_11009(level, blockPos);
        validate(level);
    }
    //?}

    //? if >1.20.5 {
    /*@Override
    protected void loadAdditional(@NotNull CompoundTag arg, HolderLookup.@NotNull Provider arg2) {
        this.write(arg);
    }

    @Override
    protected void saveAdditional(@NotNull CompoundTag arg, HolderLookup.@NotNull Provider arg2) {
        this.read(arg);
    }
    *///?} else if >1.16.5 && <1.20.5 {
    /*@Override
    public void load(CompoundTag compoundTag) {
        super.load(compoundTag);
        this.write(compoundTag);
    }

    @Override
    protected void saveAdditional(CompoundTag compoundTag) {
        super.saveAdditional(compoundTag);
        this.read(compoundTag);
    }
    *///?} else if <=1.16.5 {
    @Override
    public class_2487 method_11007(class_2487 compoundTag) {
        super.method_11007(compoundTag);
        this.read(compoundTag);
        return compoundTag;
    }

    @Override
    public void method_11014(class_2680 blockState, class_2487 compoundTag) {
        super.method_11014(blockState, compoundTag);
        this.write(compoundTag);
    }
    //?}

    protected void write(class_2487 tag) {}

    protected void read(class_2487 tag) {}

    public void validate(class_1937 level){

    }
}

==> loadmychunks-1.2.1%2B1.18.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/block/blockentity/BEBase.java <==
package com.drathonix.loadmychunks.common.block.blockentity;

import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import org.jetbrains.annotations.NotNull;

public class BEBase extends class_2586 {
    //? if >1.16.5 {
    public BEBase(class_2591<?> blockEntityType, class_2338 blockPos, class_2680 blockState) {
        super(blockEntityType, blockPos, blockState);
    }
    @Override
    public void method_31662(class_1937 level) {
        super.method_31662(level);
        validate(level);
    }
    //?} else {
    /*public BEBase(BlockEntityType<?> blockEntityType) {
        super(blockEntityType);
    }
    @Override
    public void setLevelAndPosition(Level level, BlockPos blockPos) {
        super.setLevelAndPosition(level, blockPos);
        validate(level);
    }
    *///?}

    //? if >1.20.5 {
    /*@Override
    protected void loadAdditional(@NotNull CompoundTag arg, HolderLookup.@NotNull Provider arg2) {
        this.write(arg);
    }

    @Override
    protected void saveAdditional(@NotNull CompoundTag arg, HolderLookup.@NotNull Provider arg2) {
        this.read(arg);
    }
    *///?} else if >1.16.5 && <1.20.5 {
    @Override
    public void method_11014(class_2487 compoundTag) {
        super.method_11014(compoundTag);
        this.write(compoundTag);
    }

    @Override
    protected void method_11007(class_2487 compoundTag) {
        super.method_11007(compoundTag);
        this.read(compoundTag);
    }
    //?} else if <=1.16.5 {
    /*@Override
    public CompoundTag save(CompoundTag compoundTag) {
        super.save(compoundTag);
        this.read(compoundTag);
        return compoundTag;
    }

    @Override
    public void load(BlockState blockState, CompoundTag compoundTag) {
        super.load(blockState, compoundTag);
        this.write(compoundTag);
    }
    *///?}

    protected void write(class_2487 tag) {}

    protected void read(class_2487 tag) {}

    public void validate(class_1937 level){

    }
}
